@@ -443,7 +443,6 @@ print_element_start_ (scew_printer *printer,
   static XML_Char const *END_2 = _XT("/>");
 
   scew_list *list = NULL;
-  scew_writer *writer = NULL;
   XML_Char const *name = NULL;
   XML_Char const *contents = NULL;
   scew_bool result = SCEW_TRUE;
@@ -451,8 +450,6 @@ print_element_start_ (scew_printer *printer,
   assert (printer != NULL);
   assert (element != NULL);
 
-  writer = printer->writer;
-
   name = scew_element_name (element);
 
   result = print_current_indent_ (printer);
@@ -488,15 +485,12 @@ print_element_end_ (scew_printer *printer, scew_element const *element)
   static XML_Char const *START = _XT("</");
   static XML_Char const *END = _XT(">");
 
-  scew_writer *writer = NULL;
   scew_bool result = SCEW_TRUE;
 
   XML_Char const *name = scew_element_name (element);
 
   assert (printer != NULL);
 
-  writer = printer->writer;
-
   if (scew_element_count (element) > 0)
     {
       result = print_current_indent_ (printer);
